@@ -120,6 +120,20 @@ Call C<log()> if you want to log a message as email.
 
     $email->log(message => "this message will be mailed");
 
+If you pass the level then its placed into the subject:
+
+    $email->log(message => "foo", level => "INFO");
+    $email->log(message => "bar", level => "ERROR");
+    $email->log(message => "baz", level => "DEBUG");
+
+The lowest level is used:
+
+    Subject: ERROR ...
+
+You can pass the level with C<Log::Handler> by setting
+
+    message_pattern => '%L'
+
 =head2 flush()
 
 Call C<flush()> if you want to flush the buffered messages.
@@ -161,7 +175,7 @@ Jonny Schulz <jschulz.cpan(at)bloonix.de>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2007-2009 by Jonny Schulz. All rights reserved.
+Copyright (C) 2007-2010 by Jonny Schulz. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
@@ -175,10 +189,22 @@ use warnings;
 use Carp;
 use Params::Validate qw();
 
-our $VERSION = "0.04";
+our $VERSION = "0.06";
 our $ERRSTR  = "";
 our $TEST    =  0; # is needed to disable flush() for tests
 
+my %LEVEL_BY_STRING = (
+    DEBUG     =>  7,
+    INFO      =>  6,
+    NOTICE    =>  5,
+    WARNING   =>  4,
+    ERROR     =>  3,
+    CRITICAL  =>  2,
+    ALERT     =>  1,
+    EMERGENCY =>  0,
+    FATAL     =>  0,
+);
+
 sub new {
     my $class = shift;
     my $opts  = $class->_validate(@_);
@@ -200,6 +226,11 @@ sub log {
         if ($self->{debug}) {
             warn "$class: maxsize disabled, no buffering";
         }
+
+        if ($message->{level}) {
+            $self->{level} = $message->{level};
+        }
+
         $self->{message} = $message->{message};
         return $self->_sendmail;
     }
@@ -211,6 +242,17 @@ sub log {
         $self->flush;
     }
 
+    if ($message->{level} && !$self->{level}) {
+        $self->{level} = $message->{level};
+    } elsif ($self->{level} && $message->{level}) {
+        my $slevel = $self->{level};
+        my $mlevel = $message->{level};
+
+        if ($LEVEL_BY_STRING{$slevel} > $LEVEL_BY_STRING{$mlevel}) {
+            $self->{level} = $message->{level};
+        }
+    }
+
     $self->{message} .= $message->{message};
     $self->{length}  += $length;
 
@@ -290,11 +332,18 @@ sub _sendmail {
         warn "$class: message $self->{length} bytes";
     }
 
+    if ($self->{level}) {
+        $header =~ s/Subject:(.)/Subject: $self->{level}:$1/;
+        $self->{level} = "";
+    }
+
     open my $fh, "|$sendmail"
         or return $self->raise_error("unable to execute '$self->{sendmail}' - $!");
 
     my $ret = print $fh $header, "\n", $self->{message};
 
+    close $fh;
+
     $self->{message} = "";
     $self->{length}  = 0;
 
@@ -302,8 +351,6 @@ sub _sendmail {
         return $self->raise_error("unable to write to stdin - $!");
     }
 
-    close $fh;
-
     return 1;
 }
 
@@ -361,7 +408,7 @@ sub _validate {
         },
     });
 
-    if (!-x $options{sendmail}) {
+    if (!$TEST && !-x $options{sendmail}) {
         Carp::croak "'$options{sendmail}' is not executable";
     }
 
