@@ -10,13 +10,21 @@ Just for internal usage!
 
 =head2 get_pattern
 
+=head1 PREREQUISITES
+
+    Carp
+    POSIX
+    Sys::Hostname
+    Time::HiRes
+    Log::Handler::Output
+
 =head1 AUTHOR
 
 Jonny Schulz <jschulz.cpan(at)bloonix.de>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2007 by Jonny Schulz. All rights reserved.
+Copyright (C) 2007-2010 by Jonny Schulz. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
@@ -29,11 +37,11 @@ use strict;
 use warnings;
 use POSIX;
 use Sys::Hostname;
-use Log::Handler::Output;
 use Time::HiRes;
+use Log::Handler::Output;
 use constant START_TIME => scalar Time::HiRes::gettimeofday;
 
-our $VERSION = '0.00_02';
+our $VERSION = '0.03';
 my $progname = $0;
 $progname =~ s@.*[/\\]@@;
 
@@ -51,11 +59,15 @@ sub get_pattern {
                     code => \&Sys::Hostname::hostname },
         '%N'  => {  name => 'newline',
                     code => "\n" },
-        '%C'  => {  name => 'caller',
-                    code => \&_get_caller },
         '%S'  => {  name => 'progname',
                     code => $progname },
-        '%R'  => {  name => 'runtime',
+        '%U'  => {  name => 'user',
+                    code => \&_get_user },
+        '%G'  => {  name => 'group',
+                    code => \&_get_group },
+        '%C'  => {  name => 'caller',
+                    code => \&_get_caller },
+        '%r'  => {  name => 'runtime',
                     code => \&_get_runtime },
         '%t'  => {  name => 'mtime',
                     code => \&_get_hires },
@@ -82,12 +94,14 @@ sub _get_level   { $_[1] }
 sub _get_time    { POSIX::strftime($_[0]->{timeformat}, localtime) }
 sub _get_date    { POSIX::strftime($_[0]->{dateformat}, localtime) }
 sub _get_pid     { $$ }
-sub _get_caller  { my @c = caller($_[0]->{caller_level}); "$c[1], line $c[2]" }
-sub _get_c_pkg   { (caller($_[0]->{caller_level}))[0] }
-sub _get_c_file  { (caller($_[0]->{caller_level}))[1] }
-sub _get_c_line  { (caller($_[0]->{caller_level}))[2] }
-sub _get_c_sub   { (caller($_[0]->{caller_level}))[3] }
+sub _get_caller  { my @c = caller(2+$Log::Handler::CALLER_LEVEL); "$c[1], line $c[2]" }
+sub _get_c_pkg   { (caller(2+$Log::Handler::CALLER_LEVEL))[0] }
+sub _get_c_file  { (caller(2+$Log::Handler::CALLER_LEVEL))[1] }
+sub _get_c_line  { (caller(2+$Log::Handler::CALLER_LEVEL))[2] }
+sub _get_c_sub   { (caller(2+$Log::Handler::CALLER_LEVEL))[3] }
 sub _get_runtime { return sprintf('%.6f', Time::HiRes::gettimeofday - START_TIME) }
+sub _get_user    { getpwuid($<) || $<     }
+sub _get_group   { getgrgid($(+0) || $(+0 }
 
 sub _get_hires {
     my $self = shift;
