@@ -27,7 +27,7 @@ Expect the config file name and returns the config as a reference.
             debug_mode = 2
             filename = example.log
             minlevel = warn
-            prefix = '%T %H[%P] [%L] %S: '
+            message_layout = %T %H[%P] [%L] %S: %m
             newline = 1
         </mylog>
     </file>
@@ -43,14 +43,16 @@ No exports.
 =head1 REPORT BUGS
     
 Please report all bugs to <jschulz.cpan(at)bloonix.de>.
-    
+
+If you send me a mail then add Log::Handler into the subject.
+
 =head1 AUTHOR
 
 Jonny Schulz <jschulz.cpan(at)bloonix.de>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2007 by Jonny Schulz. All rights reserved.
+Copyright (C) 2007-2010 by Jonny Schulz. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
@@ -63,7 +65,7 @@ use strict;
 use warnings;
 use Config::General;
 
-our $VERSION = '0.00_05';
+our $VERSION = '0.02';
 
 sub get_config {
     my ($class, $config_file) = @_;
